Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r67748 - in trunk/boost/chrono: . detail/inlined/mac
From: vicente.botet_at_[hidden]
Date: 2011-01-07 02:09:04


Author: viboes
Date: 2011-01-07 02:09:00 EST (Fri, 07 Jan 2011)
New Revision: 67748
URL: http://svn.boost.org/trac/boost/changeset/67748

Log:
Boost.Chrono: Try to solve some of the compile errors in

 Test output:
Rev 67722 / Thu, 6 Jan 2011 16:21:35 +0000
Report Time: Fri, 7 Jan 2011 04:23:17 +0000

Compile [2011-01-07 01:53:45 UTC]: fail

    "/Users/caj/llvmboosttest/llvm-bin/bin/clang++" -x c++ -O0 -g -O0 -fno-inline -Wall -pedantic -g -DBOOST_ALL_DYN_LINK=1 -DBOOST_ALL_NO_LIB=1 -DBOOST_SYSTEM_DYN_LINK=1 -DBOOST_SYSTEM_NO_DEPRECATED -DBOOST_USE_WINDOWS_H -I".." -c -o "/Users/caj/llvmboosttest/boosttest/results/boost/bin.v2/libs/chrono/build/clang-darwin-2.9/debug/chrono.o" "../libs/chrono/src/chrono.cpp"

In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:69:15: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(1000000000000000000)> atto;
              ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:69:40: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(1000000000000000000)> atto;
                                       ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1000000000000000000LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:70:15: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(1000000000000000)> femto;
              ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:70:43: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(1000000000000000)> femto;
                                          ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1000000000000000LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:71:15: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(1000000000000)> pico;
              ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:71:46: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(1000000000000)> pico;
                                             ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1000000000000LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:72:15: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(1000000000)> nano;
              ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:72:49: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(1000000000)> nano;
                                                ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1000000000LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:73:15: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(1000000)> micro;
              ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:73:52: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(1000000)> micro;
                                                   ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1000000LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:74:15: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(1000)> milli;
              ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:74:55: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(1000)> milli;
                                                      ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1000LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:75:15: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(100)> centi;
              ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:75:56: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(100)> centi;
                                                       ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
100LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:76:15: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(10)> deci;
              ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:76:57: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1), BOOST_RATIO_INTMAX_C(10)> deci;
                                                        ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
10LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:77:32: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(10), BOOST_RATIO_INTMAX_C(1)> deca;
                               ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
10LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:77:58: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(10), BOOST_RATIO_INTMAX_C(1)> deca;
                                                         ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:78:31: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(100), BOOST_RATIO_INTMAX_C(1)> hecto;
                              ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
100LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:78:58: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(100), BOOST_RATIO_INTMAX_C(1)> hecto;
                                                         ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:79:30: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(1000), BOOST_RATIO_INTMAX_C(1)> kilo;
                             ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1000LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:79:58: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(1000), BOOST_RATIO_INTMAX_C(1)> kilo;
                                                         ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:80:27: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(1000000), BOOST_RATIO_INTMAX_C(1)> mega;
                          ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1000000LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:80:58: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(1000000), BOOST_RATIO_INTMAX_C(1)> mega;
                                                         ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:81:24: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(1000000000), BOOST_RATIO_INTMAX_C(1)> giga;
                       ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1000000000LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:81:58: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(1000000000), BOOST_RATIO_INTMAX_C(1)> giga;
                                                         ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:82:21: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(1000000000000), BOOST_RATIO_INTMAX_C(1)> tera;
                    ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1000000000000LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:82:58: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(1000000000000), BOOST_RATIO_INTMAX_C(1)> tera;
                                                         ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:83:18: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(1000000000000000), BOOST_RATIO_INTMAX_C(1)> peta;
                 ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1000000000000000LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:83:58: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio< BOOST_RATIO_INTMAX_C(1000000000000000), BOOST_RATIO_INTMAX_C(1)> peta;
                                                         ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:84:15: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1000000000000000000), BOOST_RATIO_INTMAX_C(1)> exa;
              ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1000000000000000000LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:41:
In file included from ../boost/ratio.hpp:12:
In file included from ../boost/ratio/ratio.hpp:47:
../boost/ratio/ratio_fwd.hpp:84:58: warning: 'long long' is an extension when C99 mode is not enabled [-Wlong-long]
typedef ratio<BOOST_RATIO_INTMAX_C(1000000000000000000), BOOST_RATIO_INTMAX_C(1)> exa;
                                                         ^
../boost/ratio/ratio_fwd.hpp:37:33: note: instantiated from:
#define BOOST_RATIO_INTMAX_C(a) INTMAX_C(a)
                                ^
<scratch space>:70:1: note: instantiated from:
1LL
^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
../boost/chrono/duration.hpp:415:24: warning: extra ';' inside a class [-pedantic]
        duration() { } ;
                       ^
../boost/chrono/duration.hpp:495:10: warning: extra ';' inside a class [-pedantic]
        };
         ^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:65:
../boost/chrono/process_cpu_clocks.hpp:234:5: warning: class template 'numeric_limits' was previously declared as a struct template [-Wmismatched-tags]
    class numeric_limits<boost::chrono::process_cpu_clock::times>
    ^~~~~
    struct
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:13:
In file included from ../boost/chrono/chrono.hpp:62:
In file included from ../boost/chrono/duration.hpp:37:
/usr/include/c++/4.2.1/limits:285:12: note: previous use is here
    struct numeric_limits : public __numeric_limits_base
           ^
In file included from ../libs/chrono/src/chrono.cpp:14:
In file included from ../boost/chrono/detail/inlined/chrono.hpp:34:
../boost/chrono/detail/inlined/mac/chrono.hpp:91:5: warning: control reaches end of non-void function [-Wreturn-type]
    }
    ^
../boost/chrono/detail/inlined/mac/chrono.hpp:92:5: error: expected unqualified-id
    return mach_absolute_time();
    ^
../boost/chrono/detail/inlined/mac/chrono.hpp:113:49: error: no member named 'compute_monotonic_factor' in namespace 'boost::chrono::chrono_detail'
    static const double factor = chrono_detail::compute_monotonic_factor(err);
                                 ~~~~~~~~~~~~~~~^
../boost/chrono/detail/inlined/mac/chrono.hpp:125:49: error: no member named 'compute_monotonic_factor' in namespace 'boost::chrono::chrono_detail'
    static const double factor = chrono_detail::compute_monotonic_factor(err);
                                 ~~~~~~~~~~~~~~~^
../boost/chrono/detail/inlined/mac/chrono.hpp:144:5: error: expected unqualified-id
    return static_cast<monotonic_clock::rep>(mach_absolute_time() * factor);
    ^
../boost/chrono/detail/inlined/mac/chrono.hpp:147:9: error: use of undeclared identifier 'monotonic_clock'
typedef monotonic_clock::rep (*FP)();
        ^
../boost/chrono/detail/inlined/mac/chrono.hpp:147:26: error: C++ requires a type specifier for all declarations
typedef monotonic_clock::rep (*FP)();
~~~~~~~ ^
../boost/chrono/detail/inlined/mac/chrono.hpp:147:32: error: use of undeclared identifier 'FP'
typedef monotonic_clock::rep (*FP)();
                               ^
../boost/chrono/detail/inlined/mac/chrono.hpp:147:35: error: expected ';' after top level declarator
typedef monotonic_clock::rep (*FP)();
                                  ^
                                  ;
../boost/chrono/detail/inlined/mac/chrono.hpp:148:9: error: use of undeclared identifier 'monotonic_clock'
typedef monotonic_clock::rep (*FP_ec)(system::error_code &);
        ^
../boost/chrono/detail/inlined/mac/chrono.hpp:148:26: error: C++ requires a type specifier for all declarations
typedef monotonic_clock::rep (*FP_ec)(system::error_code &);
~~~~~~~ ^
../boost/chrono/detail/inlined/mac/chrono.hpp:148:32: error: use of undeclared identifier 'FP_ec'
typedef monotonic_clock::rep (*FP_ec)(system::error_code &);
                               ^
../boost/chrono/detail/inlined/mac/chrono.hpp:148:38: error: expected ';' after top level declarator
typedef monotonic_clock::rep (*FP_ec)(system::error_code &);
                                     ^
                                     ;
../boost/chrono/detail/inlined/mac/chrono.hpp:152:1: error: unknown type name 'FP'
FP
^
../boost/chrono/detail/inlined/mac/chrono.hpp:162:17: error: use of undeclared identifier 'chrono_detail'
        return &chrono_detail::monotonic_simplified;
                ^
../boost/chrono/detail/inlined/mac/chrono.hpp:163:13: error: use of undeclared identifier 'chrono_detail'
    return &chrono_detail::monotonic_full;
            ^
../boost/chrono/detail/inlined/mac/chrono.hpp:167:1: error: unknown type name 'FP_ec'
FP_ec
^
../boost/chrono/detail/inlined/mac/chrono.hpp:177:17: error: use of undeclared identifier 'chrono_detail'
        return &chrono_detail::monotonic_simplified_ec;
                ^
../boost/chrono/detail/inlined/mac/chrono.hpp:178:13: error: use of undeclared identifier 'chrono_detail'
    return &chrono_detail::monotonic_full_ec;
            ^
../boost/chrono/detail/inlined/mac/chrono.hpp:181:1: error: use of undeclared identifier 'monotonic_clock'
monotonic_clock::time_point
^
fatal error: too many errors emitted, stopping now [-ferror-limit=]
36 warnings and 20 errors generated.

Text files modified:
   trunk/boost/chrono/detail/inlined/mac/chrono.hpp | 111 ++++++++++++++++++++++-----------------
   trunk/boost/chrono/detail/inlined/mac/process_clock.hpp | 92 ++++++++++++++++----------------
   trunk/boost/chrono/detail/inlined/mac/process_cpu_clocks.hpp | 38 ++++++------
   trunk/boost/chrono/duration.hpp | 4
   4 files changed, 131 insertions(+), 114 deletions(-)

Modified: trunk/boost/chrono/detail/inlined/mac/chrono.hpp
==============================================================================
--- trunk/boost/chrono/detail/inlined/mac/process_clock.hpp (original)
+++ trunk/boost/chrono/detail/inlined/mac/process_clock.hpp 2011-01-07 02:09:00 EST (Fri, 07 Jan 2011)
@@ -27,57 +27,59 @@
     inline long tick_factor() // multiplier to convert ticks
                               // to nanoseconds; -1 if unknown
     {
- static long factor = 0;
- if ( !factor )
- {
- if ( (factor = ::sysconf( _SC_CLK_TCK )) <= 0 )
- factor = -1;
- else
+ static long factor = 0;
+ if ( !factor )
         {
- BOOST_ASSERT( factor <= 1000000l ); // doesn't handle large ticks
- factor = 1000000l / factor; // compute factor
- if ( !factor ) factor = -1;
+ if ( (factor = ::sysconf( _SC_CLK_TCK )) <= 0 )
+ {
+ factor = -1;
+ }
+ else
+ {
+ BOOST_ASSERT( factor <= 1000000l ); // doesn't handle large ticks
+ factor = 1000000l / factor; // compute factor
+ if ( !factor ) factor = -1;
+ }
         }
- }
- return factor;
+ return factor;
     }
- }
+}
 
     void process_clock::now( process_times & times_, system::error_code & ec )
     {
 
- tms tm;
- clock_t c = ::times( &tm );
- if ( c == -1 ) // error
- {
- if (BOOST_CHRONO_IS_THROWS(ec))
- {
- boost::throw_exception(
+ tms tm;
+ clock_t c = ::times( &tm );
+ if ( c == -1 ) // error
+ {
+ if (BOOST_CHRONO_IS_THROWS(ec))
+ {
+ boost::throw_exception(
                       system::system_error(
- errno,
- BOOST_CHRONO_SYSTEM_CATEGORY,
- "chrono::process_clock" ));
- }
- else
- {
- ec.assign( errno, BOOST_CHRONO_SYSTEM_CATEGORY );
- times_.real = times_.system = times_.user = nanoseconds(-1);
- }
- }
- else
- {
- times_.real = microseconds(c);
- times_.system = microseconds(tm.tms_stime + tm.tms_cstime);
- times_.user = microseconds(tm.tms_utime + tm.tms_cutime);
- if ( chrono_detail::tick_factor() != -1 )
+ errno,
+ BOOST_CHRONO_SYSTEM_CATEGORY,
+ "chrono::process_clock" ));
+ }
+ else
+ {
+ ec.assign( errno, BOOST_CHRONO_SYSTEM_CATEGORY );
+ times_.real = times_.system = times_.user = nanoseconds(-1);
+ }
+ }
+ else
         {
- times_.real *= chrono_detail::tick_factor();
- times_.user *= chrono_detail::tick_factor();
- times_.system *= chrono_detail::tick_factor();
- if (!BOOST_CHRONO_IS_THROWS(ec))
- {
- ec.clear();
- }
+ times_.real = microseconds(c);
+ times_.system = microseconds(tm.tms_stime + tm.tms_cstime);
+ times_.user = microseconds(tm.tms_utime + tm.tms_cutime);
+ if ( chrono_detail::tick_factor() != -1 )
+ {
+ times_.real *= chrono_detail::tick_factor();
+ times_.user *= chrono_detail::tick_factor();
+ times_.system *= chrono_detail::tick_factor();
+ if (!BOOST_CHRONO_IS_THROWS(ec))
+ {
+ ec.clear();
+ }
         }
         else
         {
@@ -95,8 +97,8 @@
                 times_.real = times_.user = times_.system = nanoseconds(-1);
             }
         }
- }
-
     }
- } // namespace chrono
+
+}
+} // namespace chrono
 } // namespace boost

Modified: trunk/boost/chrono/detail/inlined/mac/process_cpu_clocks.hpp
==============================================================================
--- trunk/boost/chrono/detail/inlined/mac/process_cpu_clocks.hpp (original)
+++ trunk/boost/chrono/detail/inlined/mac/process_cpu_clocks.hpp 2011-01-07 02:09:00 EST (Fri, 07 Jan 2011)
@@ -20,25 +20,25 @@
 
 
 namespace boost { namespace chrono {
-namespace chrono_detail
-{
- inline long tick_factor() // multiplier to convert ticks
+namespace chrono_detail {
+
+ inline long tick_factor() // multiplier to convert ticks
                             // to nanoseconds; -1 if unknown
- {
- static long factor = 0;
- if ( !factor )
- {
- if ( (factor = ::sysconf( _SC_CLK_TCK )) <= 0 )
- factor = -1;
- else
- {
- BOOST_ASSERT( factor <= 1000000l ); // doesn't handle large ticks
- factor = 1000000l / factor; // compute factor
- if ( !factor ) factor = -1;
- }
+ {
+ static long factor = 0;
+ if ( !factor )
+ {
+ if ( (factor = ::sysconf( _SC_CLK_TCK )) <= 0 )
+ factor = -1;
+ else
+ {
+ BOOST_ASSERT( factor <= 1000000l ); // doesn't handle large ticks
+ factor = 1000000l / factor; // compute factor
+ if ( !factor ) factor = -1;
+ }
+ }
+ return factor;
     }
- return factor;
- }
 }
 
 process_real_cpu_clock::time_point process_real_cpu_clock::now(
@@ -247,5 +247,5 @@
     }
     
 }
-
-} }
+}
+}

Modified: trunk/boost/chrono/duration.hpp
==============================================================================
--- trunk/boost/chrono/duration.hpp (original)
+++ trunk/boost/chrono/duration.hpp 2011-01-07 02:09:00 EST (Fri, 07 Jan 2011)
@@ -412,7 +412,7 @@
     public:
 
         BOOST_CHRONO_CONSTEXPR
- duration() { } ;
+ duration() { }
         template <class Rep2>
         BOOST_CHRONO_CONSTEXPR
         explicit duration(const Rep2& r,
@@ -493,7 +493,7 @@
         duration& operator%=(const duration& rhs)
         {
             rep_ %= rhs.count(); return *this;
- };
+ }
         // 20.9.3.4 duration special values [time.duration.special]
 
         static BOOST_CHRONO_CONSTEXPR duration zero()


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- trunk/boost/chrono/detail/inlined/mac/chrono.hpp (original)
+++ trunk/boost/chrono/detail/inlined/mac/chrono.hpp 2011-01-07 02:09:00 EST (Fri, 07 Jan 2011)
@@ -64,9 +64,9 @@
 namespace chrono_detail
 {
 
-// monotonic_clock
+// steady_clock
 
// Note, in this implementation monotonic_clock and high_resolution_clock
 // are the same clock. They are both based on mach_absolute_time().
 // mach_absolute_time() * MachInfo.numer / MachInfo.denom is the number of
 // nanoseconds since the computer booted up. MachInfo.numer and MachInfo.denom
@@ -76,17 +76,18 @@
 // MachInfo.numer / MachInfo.denom is often 1 on the latest equipment. Specialize
 // for that case as an optimization.
 BOOST_CHRONO_STATIC
-monotonic_clock::rep
-monotonic_simplified()
+steady_clock::rep
+steady_simplified()
 {
     return mach_absolute_time();
 }
 
 BOOST_CHRONO_STATIC
-monotonic_clock::rep
-monotonic_simplified_ec(system::error_code & ec)
+steady_clock::rep
+steady_simplified_ec(system::error_code & ec)
 {
- if (!BOOST_CHRONO_IS_THROWS(ec))
+ if (!BOOST_CHRONO_IS_THROWS(ec))
+ {
         ec.clear();
     }
     return mach_absolute_time();
@@ -95,117 +96,130 @@
 
 BOOST_CHRONO_STATIC
 double
-compute_monotonic_factor(kern_return_t& err)
+compute_steady_factor(kern_return_t& err)
 {
     mach_timebase_info_data_t MachInfo;
     err = mach_timebase_info(&MachInfo);
- if( err != 0 ) {
+ if ( err != 0 ) {
         return 0;
     }
     return static_cast<double>(MachInfo.numer) / MachInfo.denom;
 }
 
 BOOST_CHRONO_STATIC
-monotonic_clock::rep
-monotonic_full()
+steady_clock::rep
+steady_full()
 {
     static kern_return_t err;
- static const double factor = chrono_detail::compute_monotonic_factor(err);
- if (err != 0)
- boost::throw_exception(
- system::system_error( err, BOOST_CHRONO_SYSTEM_CATEGORY, "chrono::monotonic_clock" ));
- return static_cast<monotonic_clock::rep>(mach_absolute_time() * factor);
+ static const double factor = chrono_detail::compute_steady_factor(err);
+ if (err != 0)
+ {
+ boost::throw_exception(
+ system::system_error( err, BOOST_CHRONO_SYSTEM_CATEGORY, "chrono::steady_clock" ));
+ }
+ return static_cast<steady_clock::rep>(mach_absolute_time() * factor);
 }
 
 BOOST_CHRONO_STATIC
-monotonic_clock::rep
-monotonic_full_ec(system::error_code & ec)
+steady_clock::rep
+steady_full_ec(system::error_code & ec)
 {
     static kern_return_t err;
- static const double factor = chrono_detail::compute_monotonic_factor(err);
- if (err != 0) {
+ static const double factor = chrono_detail::compute_steady_factor(err);
+ if (err != 0)
+ {
         if (BOOST_CHRONO_IS_THROWS(ec))
         {
             boost::throw_exception(
                     system::system_error(
                             err,
                             BOOST_CHRONO_SYSTEM_CATEGORY,
- "chrono::monotonic_clock" ));
+ "chrono::steady_clock" ));
         }
         else
         {
             ec.assign( errno, BOOST_CHRONO_SYSTEM_CATEGORY );
- return monotonic_clock::rep();
+ return steady_clock::rep();
         }
     }
- if (!BOOST_CHRONO_IS_THROWS(ec))
+ if (!BOOST_CHRONO_IS_THROWS(ec))
+ {
         ec.clear();
     }
- return static_cast<monotonic_clock::rep>(mach_absolute_time() * factor);
+ return static_cast<steady_clock::rep>(mach_absolute_time() * factor);
 }
 
-typedef monotonic_clock::rep (*FP)();
-typedef monotonic_clock::rep (*FP_ec)(system::error_code &);
+typedef steady_clock::rep (*FP)();
+typedef steady_clock::rep (*FP_ec)(system::error_code &);
 
 
 BOOST_CHRONO_STATIC
 FP
-init_monotonic_clock(kern_return_t & err)
+init_steady_clock(kern_return_t & err)
 {
     mach_timebase_info_data_t MachInfo;
     err = mach_timebase_info(&MachInfo);
- if( err != 0 ) {
- return 0;
+ if ( err != 0 )
+ {
+ return 0;
     }
 
     if (MachInfo.numer == MachInfo.denom)
- return &chrono_detail::monotonic_simplified;
- return &chrono_detail::monotonic_full;
+ {
+ return &chrono_detail::steady_simplified;
+ }
+ return &chrono_detail::steady_full;
 }
 
 BOOST_CHRONO_STATIC
 FP_ec
-init_monotonic_clock_ec(kern_return_t & err)
+init_steady_clock_ec(kern_return_t & err)
 {
     mach_timebase_info_data_t MachInfo;
     err = mach_timebase_info(&MachInfo);
- if( err != 0 ) {
- return 0;
+ if ( err != 0 )
+ {
+ return 0;
     }
 
- if (MachInfo.numer == MachInfo.denom)
- return &chrono_detail::monotonic_simplified_ec;
- return &chrono_detail::monotonic_full_ec;
+ if (MachInfo.numer == MachInfo.denom)
+ {
+ return &chrono_detail::steady_simplified_ec;
+ }
+ return &chrono_detail::steady_full_ec;
 }
 }
-monotonic_clock::time_point
-monotonic_clock::now()
+
+steady_clock::time_point
+steady_clock::now()
 {
     static kern_return_t err;
- static chrono_detail::FP_ec fp = chrono_detail::init_monotonic_clock(err);
- if( err != 0 ) {
+ static chrono_detail::FP_ec fp = chrono_detail::init_steady_clock(err);
+ if ( err != 0 )
+ {
         boost::throw_exception(
                 system::system_error(
                         err,
                         BOOST_CHRONO_SYSTEM_CATEGORY,
- "chrono::monotonic_clock" ));
+ "chrono::steady_clock" ));
     }
     return time_point(duration(fp()));
 }
 
-monotonic_clock::time_point
-monotonic_clock::now(system::error_code & ec)
+steady_clock::time_point
+steady_clock::now(system::error_code & ec)
 {
     static kern_return_t err;
- static chrono_detail::FP_ec fp = chrono_detail::init_monotonic_clock(err);
- if( err != 0 ) {
+ static chrono_detail::FP_ec fp = chrono_detail::init_steady_clock(err);
+ if ( err != 0 )
+ {
         if (BOOST_CHRONO_IS_THROWS(ec))
         {
             boost::throw_exception(
                     system::system_error(
                             err,
                             BOOST_CHRONO_SYSTEM_CATEGORY,
- "chrono::monotonic_clock" ));
+ "chrono::steady_clock" ));
         }
         else
         {
@@ -213,7 +227,8 @@
             return time_point();
         }
     }
- if (!BOOST_CHRONO_IS_THROWS(ec))
+ if (!BOOST_CHRONO_IS_THROWS(ec))
+ {
         ec.clear();
     }
     return time_point(duration(fp(ec)));
@@ -64,9 +64,9 @@
 
-// Note, in this implementation monotonic_clock and high_resolution_clock
+// Note, in this implementation steady_clock and high_resolution_clock
 // are the same clock. They are both based on mach_absolute_time().
 // mach_absolute_time() * MachInfo.numer / MachInfo.denom is the number of

Modified: trunk/boost/chrono/detail/inlined/mac/process_clock.hpp
==============================================================================